@@ -18,9 +18,17 @@ from importlib import import_module
 from collections import defaultdict
 from typing import Any, Dict, Optional, Tuple, List
 
-import pkg_resources
+try:
+    # Python 3.8+
+    # pylint: disable=ungrouped-imports
+    from importlib.metadata import version  # type: ignore
+    from typing import TypedDict  # type: ignore
+except (ImportError, ModuleNotFoundError):
+    # Python < 3.8
+    from importlib_metadata import version  # type: ignore
+    from typing_extensions import TypedDict  # type: ignore
+
 import jinja2
-from typing_extensions import TypedDict
 
 import webviz_config.plugins
 from webviz_config._config_parser import SPECIAL_ARGS
@@ -69,7 +77,7 @@ def _document_plugin(plugin: Tuple[str, Any]) -> PluginInfo:
         "module": module.__name__,  # type: ignore
         "package": top_package_name,
         "package_doc": import_module(subpackage).__doc__,  # type: ignore
-        "package_version": pkg_resources.get_distribution(top_package_name).version,
+        "package_version": version(top_package_name),
     }
 
     if argspec.defaults is not None:
@@ -144,6 +152,19 @@ def build_docs(build_directory: pathlib.Path) -> None:
         build_directory,
     )
 
+    # While waiting for https://github.com/jhildenbiddle/docsify-tabs/pull/30
+    # to be reviewed, merged and released:
+    substring_prefix = (
+        r"/[\r\n]*(\s*)<!-+\s+tab:\s*(.*)\s+-+>[\r\n]+([\s\S]*?)[\r\n]*\s*"
+    )
+    docsify_tabs_file = build_directory / "docsify-tabs.min.js"
+    docsify_tabs_file.write_text(
+        docsify_tabs_file.read_text().replace(
+            substring_prefix + r"(?=<!-+\s+tabs?:)/m",
+            substring_prefix + r"(?=<!-+\s+(tab:\s*(.*)|tabs:\s*?end)\s+-+>)/m",
+        )
+    )
+
     template_environment = jinja2.Environment(  # nosec
         loader=jinja2.PackageLoader("webviz_config", "templates"),
         undefined=jinja2.StrictUndefined,
@@ -154,7 +175,7 @@ def build_docs(build_directory: pathlib.Path) -> None:
 
     template = template_environment.get_template("README.md.jinja2")
     for package_name, package_doc in plugin_documentation.items():
-        (build_directory / (package_name + ".md")).write_text(
+        (build_directory / f"{package_name}.md").write_text(
             template.render({"package_name": package_name, "package_doc": package_doc})
         )
 
@@ -163,6 +184,16 @@ def build_docs(build_directory: pathlib.Path) -> None:
         template.render({"packages": plugin_documentation.keys()})
     )
 
+    template = template_environment.get_template("webviz-doc.js.jinja2")
+    (build_directory / "webviz-doc.js").write_text(
+        template.render(
+            {
+                "paths": ["/"]
+                + [f"/{package_name}" for package_name in plugin_documentation]
+            }
+        )
+    )
+
 
 def _split_docstring(docstring: str) -> List[str]:
     """Divides docstring by splitting on ---, also unindents
